<?php

namespace SlotDb\Cli\Command\Slot;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"slot:set", aliases:[ "set" ], description:"Update the properties on a slot")]
class SlotSetCommand extends Command
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this
            ->addArgument("slot", InputArgument::REQUIRED, "Slot ID")
            ->addArgument("update", InputArgument::IS_ARRAY, "key=value pairs to update")
            ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {

        $slotId = $input->getArgument("slot");
        $updates = $input->getArgument("update");
        $props = [];
        foreach ($updates as $update) {
            if (str_contains($update, "=")) {
                [$k,$v] = explode("=", $update, 2);
                $v = json_decode($v) ?? $v;
                $props[$k] = $v;
            } else {
                $props[$update] = null;
            }
        }

        $slot = $this->client->updateSlot($slotId, $props);

        $len = 2 + max(array_map(mb_strlen(...), array_keys($slot)));
        foreach ($slot as $k=>$v) {
            $output->writeln(
                sprintf(
                    str_starts_with($k,"_")
                    ? "<fg=green>%{$len}s</>: <fg=gray>%s</>"
                    : "<fg=green;options=bold>%{$len}s</>: <fg=yellow>%s</>",
                    $k, json_encode($v)
                )
            );
        }

        return self::SUCCESS;
    }
}
